--[[
    Filename:	SC_ChaChing.lua 

    Author:		Shaun Voysey

    Based on:	SC_ChaChing by Karin of the 'Sleeper Cartel' - Perenolde server

    Version:	2.2.0

    Modified On:	7th August, 2008

    Notes:
	2.2.0	Changed to use The Interface Option --> Addons

	2.1.0	Added a GUI for setting what events to run the sounds on.

]]--


--
-- GUI Functions
--

-- This function is run on pressing the Ok or Close Buttons.
--   Sets the Status of the Saved Variables to the new settings
--
function SC_ChaChingPanel_Close()
	SC_ChaChing_Config[realm].Sold = SC_ChaChingGUIFrame_CBSold:GetChecked();
	SC_ChaChing_Config[realm].Expired = SC_ChaChingGUIFrame_CBExpired:GetChecked();
	SC_ChaChing_Config[realm].Outbid = SC_ChaChingGUIFrame_CBOutbid:GetChecked();
	SC_ChaChing_Config[realm].Removed = SC_ChaChingGUIFrame_CBRemoved:GetChecked();
  
end


-- This function is run on pressing the Cancel Button or from the VARIABLES LOADED event function.
--   Sets the status of the Check Boxes to the Values of the Saved Variables.
--
function SC_ChaChingPanel_CancelOrLoad()
	SC_ChaChingGUIFrame_CBSold:SetChecked(SC_ChaChing_Config[realm].Sold);
	SC_ChaChingGUIFrame_CBExpired:SetChecked(SC_ChaChing_Config[realm].Expired);
	SC_ChaChingGUIFrame_CBOutbid:SetChecked(SC_ChaChing_Config[realm].Outbid);
	SC_ChaChingGUIFrame_CBRemoved:SetChecked(SC_ChaChing_Config[realm].Removed);
end


-- The GUI OnLoad function.
--
function SC_ChaChingPanel_OnLoad(panel)
	-- Set the Text for the Check boxes.
	--
	SC_ChaChingGUIFrame_CBSoldText:SetText("Sold");
	SC_ChaChingGUIFrame_CBExpiredText:SetText("Expired");
	SC_ChaChingGUIFrame_CBOutbidText:SetText("outbid");
	SC_ChaChingGUIFrame_CBRemovedText:SetText("removed");

	-- Set the name for the Category for the Panel
	--
	panel.name = "_OOM Options"

	-- When the player clicks okay, set the Saved Variables to the current Check Box setting
	--
	panel.okay = function (self) SC_ChaChingPanel_Close(); end;

	-- When the player clicks cancel, set the Check Box status to the Saved Variables.
	panel.cancel = function (self)  SC_ChaChingPanel_CancelOrLoad();  end;

	-- Add the panel to the Interface Options
	--
	InterfaceOptions_AddCategory(panel);
  t_AddingPanel = GetTime();
end


-- Defined Functions
--

--Initialise all Variables.  These are saved Realm wide.
--
function SC_ChaChing_Initialise()
	-- Get Realm name and Check for validity
	--
	realm = GetCVar("realmName");

	if (SC_ChaChing_init or (not realm)) then
		return;
	end


	-- initialise Realm data structures
	--
	if (SC_ChaChing_Config == nil) then
		SC_ChaChing_Config = { };
	end

	-- Set the default list if the Realm Variable does not exist
	--
	if (SC_ChaChing_Config[realm] == nil) then
		SC_ChaChing_Config[realm] = { };

		SC_ChaChing_Config[realm].Sold = 1;
		SC_ChaChing_Config[realm].Expired = 0;
		SC_ChaChing_Config[realm].Outbid = 0;
		SC_ChaChing_Config[realm].Removed = 0;
	end

	-- Configure the False Values.  WoW does not save these.
	--
	if (SC_ChaChing_Config[realm].Sold == nil) then
		SC_ChaChing_Config[realm].Sold = 0;
	end

	if (SC_ChaChing_Config[realm].Expired == nil) then
		SC_ChaChing_Config[realm].Expired = 0;
	end

	if (SC_ChaChing_Config[realm].Outbid == nil) then
		SC_ChaChing_Config[realm].Outbid = 0;
	end

	if (SC_ChaChing_Config[realm].Removed == nil) then
		SC_ChaChing_Config[realm].Removed = 0;
	end;

	-- Set variable to say we have been through this.
	--
	SC_ChaChing_init = true;
  t_Options_init = GetTime();
end


function SC_ChaChing_OnLoad()
	-- respond to the variable being Loaded.
	--
	this:RegisterEvent("VARIABLES_LOADED");

	--respond to the System Messages in Chat.
	--
	this:RegisterEvent("CHAT_MSG_SYSTEM");
end


function SC_ChaChing_OnEvent()
	if (event == "VARIABLES_LOADED") then
		-- Register the ERR_AUCTION_SOLD_S ith the Mars Message Parser.
		--
--		MarsMessageParser_RegisterFunction("SC_ChaChing", ERR_AUCTION_SOLD_S,    function ()
--                SC_ChaChing_Sound("cashregister.wav", SC_ChaChing_Config[realm].Sold);
--          end);

		-- Register the ERR_AUCTION_EXPIRED_S with the Mars Message Parser.
		--
--		MarsMessageParser_RegisterFunction("SC_ChaChing", ERR_AUCTION_EXPIRED_S, function ()
--                SC_ChaChing_Sound("Sound1.wav", SC_ChaChing_Config[realm].Expired);
--            end);

		-- Register the ERR_AUCTION_OUTBID_S with the Mars Message Parser.
		--
--		MarsMessageParser_RegisterFunction("SC_ChaChing", ERR_AUCTION_OUTBID_S,  function ()
--                SC_ChaChing_Sound("Sound2.wav", SC_ChaChing_Config[realm].Outbid);
--            end);

		-- Register the ERR_AUCTION_REMOVED_S with the Mars Message Parser.
		--
--		MarsMessageParser_RegisterFunction("SC_ChaChing", ERR_AUCTION_REMOVED_S, function ()
--                SC_ChaChing_Sound("Sound3.wav", SC_ChaChing_Config[realm].Removed);
--            end);


		-- Initialise and set the Check Box status from the Saved Variables.
		--
		SC_ChaChing_Initialise();
		SC_ChaChingPanel_CancelOrLoad();

	elseif(event == "CHAT_MSG_SYSTEM") then
		-- We have a system Chat message,  let's see what needs to be done
		--
		--MarsMessageParser_ParseMessage("SC_ChaChing", arg1);
	end
end


function SC_ChaChing_Sound(SoundFile, PlaySound)
	if (PlaySound) then
		PlaySoundFile("Interface\\AddOns\\SC_ChaChing\\Sounds\\" .. SoundFile);
	end
end

--  CHAT_MSG_SYSTEM 
--    ERR_AUCTION_SOLD_S 
--      A buyer has been found for your auction of %s.
--      A buyer has been found for your auction of Runn Tum Tuber Surprise.

--    ERR_AUCTION_EXPIRED_S 
--      Your auction of %s has expired.
--      Your auction of Runn Tum Tuber Surprise has expired.

--    ERR_AUCTION_OUTBID_S 
--      You have been outbid on %s.
--      You have been outbid on Runn Tum Tuber Surprise.

--    ERR_AUCTION_REMOVED_S 
--      Your auction of %s has been cancelled by the seller.
--      Your auction of Runn Tum Tuber Surprise has been cancelled by the seller.
